if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt