export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho"
export ARCH="64"
export PREFIX="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho"
export BUILD_PREFIX="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_build_env"
export SYS_PREFIX="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/build_env"
export SYS_PYTHON="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/build_env/bin/python"
export SUBDIR="osx-64"
export SRC_DIR="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/work"
export ROOT="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/build_env"
export CONDA_PY="36"
export PY3K="1"
export PY_VER="3.6"
export STDLIB_DIR="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib/python3.6"
export SP_DIR="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib/python3.6/site-packages"
export PYTHON="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/bin/python"
export NPY_VER="1.11"
export CONDA_NPY="111"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.26"
export CONDA_PERL="5.26"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="3.5"
export CONDA_R="3.5"
export PKG_NAME="pymongo"
export PKG_VERSION="3.9.0"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/rsync-recipes/pymongo-3.9.0-python_3.6-on-osx"
export CPU_COUNT="4"
export LANG="en_US.UTF-8"
export LC_ALL="en_US.UTF-8"
export SHLIB_EXT=".dylib"
export PATH="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_build_env:/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_build_env/bin:/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho:/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/bin:/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/build_env/condabin:/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/build_env/bin:/opt/conda/bin:/opt/concourse/worker/volumes/live/919640f3-ac90-4f96-6ce3-fd18ef758625/volume/build_env/bin:/Users/builder/miniconda3/bin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin:/opt/X11/bin:/Library/TeX/texbin"
export HOME="/var/root"
export PKG_CONFIG_PATH="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export OSX_ARCH="x86_64"
export MACOSX_DEPLOYMENT_TARGET="10.9"
export BUILD="x86_64-apple-darwin13.4.0"
export r_base="3.5"
export cpu_optimization_target="nocona"
export cran_mirror="https://mran.microsoft.com/snapshot/2018-01-01"
export target_platform="osx-64"
export c_compiler="clang"
export cxx_compiler="clangxx"
export fortran_compiler="gfortran"
export apr="1.6.3"
export blas_impl="openblas"
export boost="1.67"
export bzip2="1.0"
export cairo="1.14"
export rust_compiler="rust"
export rust_compiler_version="1.34.1"
export CONDA_BUILD_SYSROOT="/opt/MacOSX10.10.sdk"
export VERBOSE_AT="V=1"
export VERBOSE_CM="VERBOSE=1"
export ctng_binutils="2.31.1"
export ctng_duma="2.5.15"
export ctng_gmp="6.1.2"
export ctng_isl="0.19"
export ctng_libc="gnu"
export ctng_kernel="2.6.32"
export ctng_libiconv="1.15"
export ctng_mpc="1"
export ctng_nature="shared"
export ctng_ncurses="6.1"
export clang_variant="clang"
export cyrus_sasl="2.1.26"
export dbus="1"
export expat="2.2"
export fontconfig="2.13"
export freetype="2.9"
export g2clib="1.6"
export gstreamer="1.14"
export gst_plugins_base="1.14"
export geos="3.7.1"
export giflib="5.1"
export glib="2.56"
export gmp="6.1"
export gnu="2.12.2"
export harfbuzz="1.7"
export hdf4="4.2"
export hdf5="1.10.4"
export hdfeos2="2.20"
export hdfeos5="5.1"
export icu="58"
export jpeg="9"
export libdap4="3.19"
export libffi="3.2"
export libgd="2.2.5"
export libgdal="2.3"
export libgsasl="1.8"
export libkml="1.3"
export libnetcdf="4.6"
export libpng="1.6"
export libtiff="4.0"
export libwebp="1.0.0"
export libxml2="2.9"
export libxslt="1.1"
export llvm_variant="llvm"
export lzo="2"
export macos_min_version="10.9"
export macos_machine="x86_64-apple-darwin13.4.0"
export mkl="2019"
export mpfr="4"
export nodejs="8.12"
export openblas="0.3.3"
export openjpeg="2.3"
export openssl="1.1.1"
export pixman="0.34"
export proj4="5.2.0"
export libprotobuf="3.6.0"
export r_version="3.5.0"
export r_implementation="r-base"
export serf="1.3.9"
export sqlite="3"
export tk="8.6"
export zlib="1.2"
export xz="5"
export qtwebkit="true"
export ctng_gcc_activation_build_num="8"
export ctng_gcc_build_number="2"
export zip_keys="[['ctng_gcc', 'ctng_gcc_build_number', 'ctng_gcc_activation_build_num']]"
export pin_run_as_build="OrderedDict([('python', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('r-base', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('libboost', {'max_pin': 'x.x.x'})])"
export ctng_gcc="7.3.0"
export extend_keys="{'pin_run_as_build', 'extend_keys', 'ignore_version', 'ignore_build_only_deps'}"
export ignore_build_only_deps="{'numpy', 'python'}"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/build_env/bin/python' -m conda shell.bash hook)"
conda activate "/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho"
conda activate --stack "/opt/concourse/worker/volumes/live/f57840bc-2768-40d1-5f5e-5516160def52/volume/pymongo_1569345357257/_build_env"
